%define major		1
%define libname		%mklibname x86_ %{major}
%define develname	%mklibname x86 -d

Name:		libx86
Version:	1.1
Release:	%mkrel 42
Summary:	Hardware-independent library for executing real-mode x86 code
Group:		System/Libraries
License:	MIT
URL:		https://www.codon.org.uk/~mjg59/libx86/
Source0:	https://www.codon.org.uk/~mjg59/libx86/downloads/%{name}-%{version}.tar.gz
# Fedora patches:
Patch0:		libx86-add-pkgconfig.patch
# Attempt to make selinux happy by not mmap'ing the zero page. 
# but also fix segfault (mga#13676):
Patch1:		libx86-mmap-offset.patch
# patch from  https://bugs.debian.org/cgi-bin/bugreport.cgi?msg=34;filename=libx86-libc-test.patch.txt;att=1;bug=570676
# debian control portion removed as it fails to apply and we do not need it anyway
# fix on !x86:
Patch2:		libx86-libc-test.patch
# fix invalid HLT opcode
Patch5:         libx86-1.1-24-fix-invalid-hlt-opcode.patch
# fix build by passing -fPIC to the sub-make for the shared lib
Patch6:		libx86-1.1-staticsharedcflags.patch
Patch7:		libx86-0.99-ifmask.patch
# fix mmap failures due to /dev/zero and /dev/mem no longer allowing exec permission
# (martinw) reverted for now, as it seems to cause problems on some hardware
Patch8:		libx86-1.1-fix-mmap-permissions.patch
Patch9:		libx86-c99.patch
Patch10:	libx86-c99-2.patch 
ExcludeArch:    ppc %{power64} s390 s390x %{sparc} aarch64 armv7hl


%description
It's often useful to be able to make real-mode x86 BIOS calls from userland.
lrmi provides a simple interface to this for x86 machines, but this doesn't
help on other platforms.

libx86 provides the lrmi interface, but will also run on platforms such as
amd64 and alpha.

%package -n	%{libname}
Summary:	Hardware-independent library for executing real-mode x86 code
Group:		System/Libraries
Obsoletes:	%{_lib}x861 < 1.1-34

%description -n	%{libname}
It's often useful to be able to make real-mode x86 BIOS calls from userland.
lrmi provides a simple interface to this for x86 machines, but this doesn't
help on other platforms.

libx86 provides the lrmi interface, but will also run on platforms such as
amd64 and alpha.

This package contains the library needed to run programs dynamically
linked with %{name}.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
This package contains the static library and header file necessary for
development of programs that will use libx86 to make real-mode x86 calls.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 5 -p1 -b .hlt
%patch -P 6 -p1 -b .pic
%patch -P 7 -p0 -b .ifmask
#patch -P 8 -p1 -b .mmap
%patch -P 9 -p1 -b .c99
%patch -P 10 -p1 -b .c99-2


%build
%ifarch %{ix86}
%make_build CFLAGS="%{optflags} -fPIC"
%else
%make_build BACKEND="x86emu" CFLAGS="%{optflags} -fPIC -DX86EMU"
%endif

%install
make install DESTDIR=%{buildroot} LIBDIR=%{_libdir}
rm $RPM_BUILD_ROOT/%{_libdir}/*.a

%files -n %{libname}
%doc COPYRIGHT
%{_libdir}/libx86.so.%{major}

%files -n %{develname}
%{_libdir}/libx86.so
%{_includedir}/libx86.h
%{_libdir}/pkgconfig/x86.pc


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 1.1-42.mga10
+ Revision: 2229041
- Mageia 10 Mass Rebuild

* Fri Oct 18 2024 daviddavid <daviddavid> 1.1-41.mga10
+ Revision: 2108019
- add fedora patches to fix build with GCC 14

* Tue Mar 15 2022 umeabot <umeabot> 1.1-40.mga9
+ Revision: 1793388
- Mageia 9 Mass Rebuild

* Tue Jan 26 2021 martinw <martinw> 1.1-39.mga8
+ Revision: 1673583
- revert mmap fix, it causes problems on some hardware

* Tue Jan 26 2021 martinw <martinw> 1.1-38.mga8
+ Revision: 1673365
- fix mmap failures due to /dev/zero and /dev/mem no longer allowing exec permission

* Tue Feb 18 2020 pterjan <pterjan> 1.1-37.mga8
+ Revision: 1538046
- Also exclude armv7hl, and cleanup patches

* Thu Feb 13 2020 umeabot <umeabot> 1.1-36.mga8
+ Revision: 1514558
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 1.1-35.mga7
+ Revision: 1299232
- Mageia 7 Mass Rebuild

* Fri Jun 15 2018 wally <wally> 1.1-34.mga7
+ Revision: 1237130
- fix lib pkg name

* Fri Jun 15 2018 pterjan <pterjan> 1.1-33.mga7
+ Revision: 1237054
- Disable architectures without io routing

* Thu Jun 16 2016 pterjan <pterjan> 1.1-32.mga6
+ Revision: 1021827
- Try fixing build on arm

* Thu Jun 16 2016 tv <tv> 1.1-31.mga6
+ Revision: 1021803
- new std build_macros

* Wed Jun 15 2016 tv <tv> 1.1-30.mga6
+ Revision: 1021540
- drop static library

* Thu Mar 17 2016 pterjan <pterjan> 1.1-29.mga6
+ Revision: 992611
- Use x86emu on everything except i586 and do not restict arches

* Sat Feb 20 2016 umeabot <umeabot> 1.1-28.mga6
+ Revision: 971835
- Mageia 6 Mass Rebuild

* Tue Oct 20 2015 tv <tv> 1.1-27.mga6
+ Revision: 893111
- fix build: use -fPIC
+ cjw <cjw>
- patch6: fix build (CFLAGS vs. -fPIC)

* Mon Jun 08 2015 luigiwalser <luigiwalser> 1.1-26.mga5
+ Revision: 822949
- rebuild for release

* Mon Jun 08 2015 luigiwalser <luigiwalser> 1.1-25.mga5
+ Revision: 822945
- only apply patch 2 on x86_64

* Wed May 20 2015 eatdirt <eatdirt> 1.1-24.mga5
+ Revision: 822441
- Restoring patch 2 to fix segfault mga#13676 + fixing patch4
- Add BACKEND=x86emu on x86_64 build
+ luigiwalser <luigiwalser>
- disable x86emu backend also on x86_64 (mga#13676)

* Thu Apr 09 2015 luigiwalser <luigiwalser> 1.1-23.mga5
+ Revision: 819951
- disable patch 2 and do not build with x86emu on i586
- this fixes vbetool (mga#3910) and monitor-get-edid-using-vbe (mga#13961)

* Sun Mar 15 2015 tmb <tmb> 1.1-22.mga5
+ Revision: 818628
- rebuild for missing signature

* Sun Mar 15 2015 tmb <tmb> 1.1-21.mga5
+ Revision: 818580
- re-apply p2 to prevent illegal instruction crashes

* Wed Feb 25 2015 tmb <tmb> 1.1-20.mga5
+ Revision: 816996
- build with x86emu on i586 too

* Wed Feb 25 2015 tmb <tmb> 1.1-19.mga5
+ Revision: 816969
- fix invalid HLT opcode (tv)

* Tue Feb 24 2015 tv <tv> 1.1-18.mga5
+ Revision: 816808
- disable patch 2 which breaks vbetool (mga#3910)
  (the mga#13676 segfault seems fixed with newer gcc/glibc anyway)

* Wed Oct 15 2014 umeabot <umeabot> 1.1-17.mga5
+ Revision: 739226
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.1-16.mga5
+ Revision: 681864
- Mageia 5 Mass Rebuild

* Sat Jul 05 2014 tv <tv> 1.1-15.mga5
+ Revision: 643430
- add FC patches:
  o attempt to make selinux happy by not mmap'ing the zero page.
    but also fix segfault (mga#13676)
  o fix on !x86

* Thu Jun 19 2014 tv <tv> 1.1-14.mga5
+ Revision: 638112
- drop uclibc build

* Fri Oct 18 2013 umeabot <umeabot> 1.1-13.mga4
+ Revision: 507476
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 1.1-12.mga3
+ Revision: 358501
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Aug 15 2011 tv <tv> 1.1-11.mga2
+ Revision: 133359
- actually ship pkgconfig file
- add pkgconfig support (needed for eg vbetool)

* Sat Jan 15 2011 blino <blino> 1.1-9.mga1
+ Revision: 18795
- remove old ldconfig scriptlets
- imported package libx86


* Sun Nov 28 2010 Oden Eriksson <oeriksson@mandriva.com> 1.1-8mdv2011.0
+ Revision: 602618
- rebuild

* Sat Dec 05 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.1-7mdv2010.1
+ Revision: 473683
- cosmetics...
- correct license tag
- build uclibc linked static library

* Sun Sep 27 2009 Olivier Blin <oblin@mandriva.com> 1.1-6mdv2010.0
+ Revision: 450113
- build on x86_64 too
- build on ix86 only (from Arnaud Patard)

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 1.1-5mdv2010.0
+ Revision: 425881
- rebuild

* Fri Apr 10 2009 Funda Wang <fwang@mandriva.org> 1.1-4mdv2009.1
+ Revision: 365805
- use fpic
- fix ifmask (patch from gentoo)

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon May 19 2008 Pascal Terjan <pterjan@mandriva.org> 1.1-2mdv2009.0
+ Revision: 209214
- Fix make install on x86_64
- Update to 1.1

* Mon May 19 2008 Pascal Terjan <pterjan@mandriva.org> 1.0-2mdv2009.0
+ Revision: 208851
- Fix build on non x86
- First version of the package


